summaryrefslogtreecommitdiffstats
path: root/src/gui/listview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/listview.h')
-rw-r--r--src/gui/listview.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/gui/listview.h b/src/gui/listview.h
index 47d3e8e..8e0be06 100644
--- a/src/gui/listview.h
+++ b/src/gui/listview.h
@@ -40,7 +40,7 @@ typedef TQPtrListIterator<ListViewItem> ListViewItemListIt;
*
* @author Robby Stephenson
*/
-class ListView : public KListView {
+class ListView : public TDEListView {
Q_OBJECT
@@ -130,13 +130,13 @@ private:
*
* @author Robby Stephenson
*/
-class ListViewItem : public KListViewItem {
+class ListViewItem : public TDEListViewItem {
public:
- ListViewItem(ListView* parent) : KListViewItem(parent), m_sortWeight(-1) {}
- ListViewItem(ListView* parent, TQListViewItem* after) : KListViewItem(parent, after), m_sortWeight(-1) {}
- ListViewItem(ListViewItem* parent) : KListViewItem(parent), m_sortWeight(-1) {}
- ListViewItem(ListView* parent, const TQString& text) : KListViewItem(parent, text), m_sortWeight(-1) {}
- ListViewItem(ListViewItem* parent, const TQString& text) : KListViewItem(parent, text), m_sortWeight(-1) {}
+ ListViewItem(ListView* parent) : TDEListViewItem(parent), m_sortWeight(-1) {}
+ ListViewItem(ListView* parent, TQListViewItem* after) : TDEListViewItem(parent, after), m_sortWeight(-1) {}
+ ListViewItem(ListViewItem* parent) : TDEListViewItem(parent), m_sortWeight(-1) {}
+ ListViewItem(ListView* parent, const TQString& text) : TDEListViewItem(parent, text), m_sortWeight(-1) {}
+ ListViewItem(ListViewItem* parent, const TQString& text) : TDEListViewItem(parent, text), m_sortWeight(-1) {}
virtual ~ListViewItem();
virtual int realChildCount() const { return childCount(); }
@@ -160,11 +160,11 @@ public:
* @param column The column number
* @param alternate The alternate row color can be forced
*/
- virtual TQColor backgroundColor(int column); // not virtual in KListViewItem!!!
+ virtual TQColor backgroundColor(int column); // not virtual in TDEListViewItem!!!
virtual void paintCell(TQPainter* painter, const TQColorGroup& colorGroup,
int column, int width, int alignment);
- ListView* listView () const { return static_cast<ListView*>(KListViewItem::listView()); }
+ ListView* listView () const { return static_cast<ListView*>(TDEListViewItem::listView()); }
virtual void doubleClicked() {}
virtual Data::EntryVec entries() const;